---
title: "LSM303D"
linkTitle: "LSM303D"
weight: 4
description: >
  STMicroelectronics accelerometer and magnetometer
---

## Registers

### Accelerometer X
Raw accelerometer data on X plane

### Accelerometer X
Raw accelerometer data on X plane

### Accelerometer Y
Raw accelerometer data on Y plane

### Accelerometer Y
Raw accelerometer data on Y plane

### Accelerometer Z
Raw accelerometer data on Z plane

### Accelerometer Z
Raw accelerometer data on Z plane

### Magnetometer X
Raw magnetometer data on X plane

### Magnetometer X
Raw magnetometer data on X plane

### Magnetometer Y
Raw magnetometer data on Y plane

### Magnetometer Y
Raw magnetometer data on Y plane

### Magnetometer Z
Raw magnetometer data on Z plane

### Magnetometer Z
Raw magnetometer data on Z plane

## License
Licensed under [Apache-2.0](https://spdx.org/licenses/Apache-2.0.html#licenseText).

_LSM303D version 0.1.0_

_Based on Cyanobyte spec version 0.1.0_

_Generated from Cyanobyte Codegen version 0.1.0_